Loss Functions
==============
.. automodapi:: pykeen.losses
    :no-heading:
    :headings: --
    :skip: Loss
    :include-all-objects:


Base Classes
------------
.. autoclass:: pykeen.losses.Loss
    :members:
